<p align="center">
    <img width="200px" src="https://github.com/rcpch/digital-growth-charts-documentation/raw/live/docs/_assets/_images/rcpch_logo.png"/>
    <p align="center">Designed and built by the RCPCH, by clinicians for clinicians.</p>
</p>
<p align="center">
    <img align="center" width="100px" src="https://github.com/rcpch/digital-growth-charts-documentation/raw/live/docs/_assets/_images/htn-awards-winner-2020-logo.jpg"/>
    <img align="center" width="100px" src="https://github.com/rcpch/digital-growth-charts-documentation/raw/live/docs/_assets/_images/logo-block-outline-sm.png"/>
    <p align="center">Winner 2020 HTN Health Tech Awards - Best Health Tech Solution</p>
    <p align="center">This project is part of the <a href="https://publicmoneypubliccode.org.uk/">Public Money Public Code</a> community</p>
</p>

# RCPCHGrowth

[![DOI](https://zenodo.org/badge/361149103.svg)](https://zenodo.org/badge/latestdoi/361149103)

A python package to produce calculations for child growth parameters, produced and validated by The Royal College of Paediatrics and Child Health ([RCPCH](https://rcpch.ac.uk/)).

All documentation for implementation can be found [here](https://growth.rcpch.ac.uk/)
